package com.alterdekim.game.controller;

import com.alterdekim.game.storage.FileSystemStorageService;
import com.alterdekim.game.storage.StorageFileNotFoundException;
import com.alterdekim.game.storage.StorageProperties;
import jakarta.servlet.http.HttpServletRequest;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.context.properties.EnableConfigurationProperties;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import java.nio.file.Files;
import java.nio.file.Path;

@Slf4j
@RestController
@EnableConfigurationProperties(StorageProperties.class)
public class FileServerController {

    @Autowired
    private FileSystemStorageService storageService;

    @RequestMapping(value = "/static/{*resPath}", method = RequestMethod.GET)
    @ResponseBody
    public ResponseEntity<byte[]> serveFile(@PathVariable("resPath") String resPath, HttpServletRequest request) {
        try {
            String filename = request.getRequestURL().substring(request.getRequestURL().indexOf("/static/")+8);
            Path path = storageService.load(filename);
            return ResponseEntity.ok().contentType(switch(resPath.substring(1, 4)) {
                case "swf" -> MediaType.parseMediaType("application/x-shockwave-flash");
                case "css" -> MediaType.parseMediaType("text/css");
                case "_js" -> MediaType.parseMediaType("text/javascript");
                case "img" -> MediaType.parseMediaType("image/jpeg");
                default -> MediaType.TEXT_PLAIN;
            }).body(Files.readAllBytes(path));
        } catch (Exception e) {
            log.error(e.getMessage());
        }
        return ResponseEntity.notFound().build();
    }

    @ExceptionHandler(StorageFileNotFoundException.class)
    public ResponseEntity<?> handleStorageFileNotFound(StorageFileNotFoundException exc) {
        return ResponseEntity.notFound().build();
    }
}

